@@ -3,7 +3,7 @@
  * Purpose:     wxMediaLine (internal class for wxMediaEdit) implementation
  * Author:      Matthew Flatt
  * Created:     1995
- * Copyright:   (c) 2004-2008 PLT Scheme Inc.
+ * Copyright:   (c) 2004-2009 PLT Scheme Inc.
  * Copyright:   (c) 1995, Matthew Flatt
 
     This library is free software; you can redistribute it and/or
@@ -321,7 +321,7 @@ void wxMediaLine::Delete(wxMediaLine **root)
   else
     x = v->right;
 
-  x->parent = v->parent;
+  x->parent = v->parent; /* x could be NIL; fixup at end */
 
   if (PTREQ(v->parent, NIL))
     *root = x;
@@ -448,6 +448,11 @@ void wxMediaLine::Delete(wxMediaLine **root)
     SET_BLACK(x);
   }
 
+  if (PTRNE(NIL->parent, NIL)) {
+    /* fixup: we set NIL's parent above */
+    NIL->parent = NIL;
+  }
+
   right = left = NIL;
   DELETE_OBJ this;
 }
@@ -594,7 +599,8 @@ wxMediaParagraph *wxMediaLine::GetParagraphStyle(Bool *first)
     } else {                                 \
       node = node->parent;                   \
     }                                        \
-  }                                          \
+  }
+
 
 void wxMediaLine::SetLength(long len)
 {
