@@ -355,8 +355,10 @@ cont_proc {
   MARK_cjs(&c->cjs);
   MARK_stack_state(&c->ss);
   gcMARK(c->barrier_prompt);
-  gcMARK(c->runstack_start);
-  gcMARK(c->runstack_saved);
+  if (!GC_merely_accounting()) {
+    gcMARK(c->runstack_start);
+    gcMARK(c->runstack_saved);
+  }
 
   gcMARK(c->prompt_id);
   gcMARK(c->prompt_buf);
@@ -615,12 +617,16 @@ thread_val {
   gcMARK(pr->init_config);
   gcMARK(pr->init_break_cell);
 
-  {
+  if (!pr->runstack_owner
+      || !GC_merely_accounting()
+      || (*pr->runstack_owner == pr)) {
     Scheme_Object **rs = pr->runstack_start;
     gcFIXUP_TYPED_NOW(Scheme_Object **, pr->runstack_start);
-    pr->runstack = pr->runstack_start + (pr->runstack - rs);
+    if (pr->runstack != pr->runstack_start + (pr->runstack - rs))
+      pr->runstack = pr->runstack_start + (pr->runstack - rs);
+
+    gcMARK(pr->runstack_saved);
   }
-  gcMARK(pr->runstack_saved);
   gcMARK(pr->runstack_owner);
   gcMARK(pr->runstack_swapped);
   pr->spare_runstack = NULL; /* just in case */
@@ -738,7 +744,8 @@ prompt_val {
  mark: 
   Scheme_Prompt *pr = (Scheme_Prompt *)p;
   gcMARK(pr->boundary_overflow_id);
-  gcMARK(pr->runstack_boundary_start);
+  if (!GC_merely_accounting())
+    gcMARK(pr->runstack_boundary_start);
   gcMARK(pr->tag);
   gcMARK(pr->id);
  size:
@@ -870,7 +877,7 @@ resolve_prefix_val {
   Resolve_Prefix *rp = (Resolve_Prefix *)p;
   gcMARK(rp->toplevels);
   gcMARK(rp->stxes);
-  gcMARK(rp->delay_info);
+  gcMARK(rp->delay_info_rpair);
 
  size:
   gcBYTES_TO_WORDS(sizeof(Resolve_Prefix));
@@ -937,6 +944,8 @@ module_val {
   gcMARK(m->provide_protects);
   gcMARK(m->indirect_provides);
 
+  gcMARK(m->indirect_syntax_provides);
+
   gcMARK(m->et_provide_protects);
   gcMARK(m->et_indirect_provides);
 
@@ -1114,6 +1123,7 @@ mark_comp_env {
   gcMARK(e->data.const_names);
   gcMARK(e->data.const_vals);
   gcMARK(e->data.const_uids);
+  gcMARK(e->data.sealed);
   gcMARK(e->data.use);
   gcMARK(e->data.lifts);
 
@@ -1421,14 +1431,6 @@ mark_input_file {
   gcBYTES_TO_WORDS(sizeof(Scheme_Input_File));
 }
 
-#if defined(WIN32_FD_HANDLES)
-mark_tcp_select_info {
- mark:
- size:
-  gcBYTES_TO_WORDS(sizeof(Tcp_Select_Info));
-}
-#endif
-
 mark_output_file {
  mark:
   Scheme_Output_File *o = (Scheme_Output_File *)p;
@@ -2118,6 +2120,8 @@ lex_rib {
  mark:
   Scheme_Lexical_Rib *rib = (Scheme_Lexical_Rib *)p;
   gcMARK(rib->rename);
+  gcMARK(rib->timestamp);
+  gcMARK(rib->sealed);
   gcMARK(rib->next);
  size:
   gcBYTES_TO_WORDS(sizeof(Scheme_Lexical_Rib));
