@@ -1,6 +1,6 @@
 /*
   MzScheme
-  Copyright (c) 2004-2008 PLT Scheme Inc.
+  Copyright (c) 2004-2009 PLT Scheme Inc.
   Copyright (c) 1995-2001 Matthew Flatt
   All rights reserved.
 
@@ -82,6 +82,8 @@ MZ_EXTERN Scheme_Thread *scheme_get_current_thread();
 MZ_EXTERN void scheme_start_atomic(void);
 MZ_EXTERN void scheme_end_atomic(void);
 MZ_EXTERN void scheme_end_atomic_no_swap(void);
+MZ_EXTERN void scheme_start_in_scheduler(void);
+MZ_EXTERN void scheme_end_in_scheduler(void);
 
 MZ_EXTERN void scheme_out_of_fuel(void);
 
@@ -120,6 +122,9 @@ MZ_EXTERN int scheme_in_main_thread(void);
 
 MZ_EXTERN void scheme_cancel_sleep(void);
 
+MZ_EXTERN void scheme_start_sleeper_thread(void (*mzsleep)(float seconds, void *fds), float secs, void *fds, int hit_fd);
+MZ_EXTERN void scheme_end_sleeper_thread();
+
 MZ_EXTERN Scheme_Object *scheme_make_thread_cell(Scheme_Object *def_val, int inherited);
 MZ_EXTERN Scheme_Object *scheme_thread_cell_get(Scheme_Object *cell, Scheme_Thread_Cell_Table *cells);
 MZ_EXTERN void scheme_thread_cell_set(Scheme_Object *cell, Scheme_Thread_Cell_Table *cells, Scheme_Object *v);
@@ -870,6 +875,7 @@ MZ_EXTERN void scheme_fdclr(void *fd, int pos);
 MZ_EXTERN int scheme_fdisset(void *fd, int pos);
 MZ_EXTERN void scheme_add_fd_handle(void *h, void *fds, int repost);
 MZ_EXTERN void scheme_add_fd_eventmask(void *fds, int mask);
+MZ_EXTERN void scheme_collapse_win_fd(void *fds);
 
 MZ_EXTERN void scheme_security_check_file(const char *who, const char *filename, int guards);
 MZ_EXTERN void scheme_security_check_file_link(const char *who, const char *filename, const char *content);
