@@ -31,6 +31,8 @@
 #define scheme_start_atomic (scheme_extension_table->scheme_start_atomic)
 #define scheme_end_atomic (scheme_extension_table->scheme_end_atomic)
 #define scheme_end_atomic_no_swap (scheme_extension_table->scheme_end_atomic_no_swap)
+#define scheme_start_in_scheduler (scheme_extension_table->scheme_start_in_scheduler)
+#define scheme_end_in_scheduler (scheme_extension_table->scheme_end_in_scheduler)
 #define scheme_out_of_fuel (scheme_extension_table->scheme_out_of_fuel)
 #define scheme_thread (scheme_extension_table->scheme_thread)
 #define scheme_thread_w_details (scheme_extension_table->scheme_thread_w_details)
@@ -51,6 +53,8 @@
 #define scheme_unless_ready (scheme_extension_table->scheme_unless_ready)
 #define scheme_in_main_thread (scheme_extension_table->scheme_in_main_thread)
 #define scheme_cancel_sleep (scheme_extension_table->scheme_cancel_sleep)
+#define scheme_start_sleeper_thread (scheme_extension_table->scheme_start_sleeper_thread)
+#define scheme_end_sleeper_thread (scheme_extension_table->scheme_end_sleeper_thread)
 #define scheme_make_thread_cell (scheme_extension_table->scheme_make_thread_cell)
 #define scheme_thread_cell_get (scheme_extension_table->scheme_thread_cell_get)
 #define scheme_thread_cell_set (scheme_extension_table->scheme_thread_cell_set)
@@ -508,6 +512,7 @@
 #define scheme_fdisset (scheme_extension_table->scheme_fdisset)
 #define scheme_add_fd_handle (scheme_extension_table->scheme_add_fd_handle)
 #define scheme_add_fd_eventmask (scheme_extension_table->scheme_add_fd_eventmask)
+#define scheme_collapse_win_fd (scheme_extension_table->scheme_collapse_win_fd)
 #define scheme_security_check_file (scheme_extension_table->scheme_security_check_file)
 #define scheme_security_check_file_link (scheme_extension_table->scheme_security_check_file_link)
 #define scheme_security_check_network (scheme_extension_table->scheme_security_check_network)
